GogApi


Sort Type

All possible ways to sort with a custom field for new sorting ways which are not in this API wrapper yet

Union cases

Union case Description

Alphabetically

Full Usage: Alphabetically

BestSelling

Full Usage: BestSelling

BestSellingAllTime

Full Usage: BestSellingAllTime

Custom string

Full Usage: Custom string

Parameters:
    Item : string

Item : string

DateAdded

Full Usage: DateAdded

NewestFirst

Full Usage: NewestFirst

OldestFirst

Full Usage: OldestFirst

UserRating

Full Usage: UserRating