All possible ways to sort with a custom field for new sorting ways which are not in this API wrapper yet
| Union case | Description |
Full Usage:
Alphabetically
|
|
Full Usage:
BestSelling
|
|
Full Usage:
BestSellingAllTime
|
|
Full Usage:
Custom string
Parameters:
string
|
|
Full Usage:
DateAdded
|
|
Full Usage:
NewestFirst
|
|
Full Usage:
OldestFirst
|
|
Full Usage:
UserRating
|